summaryrefslogtreecommitdiffstats
path: root/karbon/core/vcursor.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /karbon/core/vcursor.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/core/vcursor.h')
-rw-r--r--karbon/core/vcursor.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/karbon/core/vcursor.h b/karbon/core/vcursor.h
index 84c89648..90ab1673 100644
--- a/karbon/core/vcursor.h
+++ b/karbon/core/vcursor.h
@@ -20,14 +20,14 @@
#ifndef __VCURSOR_H__
#define __VCURSOR_H__
-#include <qcursor.h>
+#include <tqcursor.h>
#include <koffice_export.h>
/**
* A helper class for easily creating cursors from XPMs.
*
* One can create a predefined unthemed cursor or create a cursor from two given XMPs,
* the cursor bitmap and the cursor mask.
*/
class KARBONBASE_EXPORT VCursor
{
@@ -47,24 +47,24 @@ public:
* @param type the requested cursor id
* @return the predefined cursor
*/
- static QCursor createCursor( CursorType type );
+ static TQCursor createCursor( CursorType type );
/**
* Creates a cursor from two specified XPM images.
* This is only a wrapper function for a QCursor ctor.
*/
- static QCursor createCursor( const char * bitmap[], const char * mask[], int hotX = -1, int hotY = -1 );
+ static TQCursor createCursor( const char * bitmap[], const char * tqmask[], int hotX = -1, int hotY = -1 );
/** crosshair cursor */
- static QCursor crossHair();
+ static TQCursor crossHair();
/** needle arraow cursor */
- static QCursor needleArrow();
+ static TQCursor needleArrow();
/** needle arrow with four way arrow */
- static QCursor needleMoveArrow();
+ static TQCursor needleMoveArrow();
- static QCursor horzMove();
+ static TQCursor horzMove();
private:
// prevent instantiation
@@ -20,14 +20,14 @@
*
* One can create a predefined unthemed cursor or create a cursor from two given XMPs,
-* the cursor bitmap and the cursor mask.
+* the cursor bitmap and the cursor tqmask.
*/
class KARBONBASE_EXPORT VCursor
@@ -47,24 +47,24 @@ public:
/**
* Creates a cursor from two specified XPM images.
- * This is only a wrapper function for a QCursor ctor.
+ * This is only a wrapper function for a TQCursor ctor.
*/